Class OrderKeyReferenceImpl

java.lang.Object
com.commercetools.importapi.models.common.OrderKeyReferenceImpl
All Implemented Interfaces:
KeyReference, OrderKeyReference, io.vrap.rmf.base.client.ModelBase

public class OrderKeyReferenceImpl extends Object implements OrderKeyReference, io.vrap.rmf.base.client.ModelBase

References an order by key.

  • Constructor Details

    • OrderKeyReferenceImpl

      public OrderKeyReferenceImpl()
      create empty instance
  • Method Details

    • getKey

      public String getKey()

      User-defined unique identifier of the referenced resource. If the referenced resource does not exist, the state of the ImportOperation will be set to unresolved until the referenced resource is created.

      Specified by:
      getKey in interface KeyReference
      Returns:
      key
    • getTypeId

      public ReferenceType getTypeId()

      Type of referenced resource.

      Specified by:
      getTypeId in interface KeyReference
      Returns:
      typeId
    • setKey

      public void setKey(String key)
      Description copied from interface: KeyReference

      User-defined unique identifier of the referenced resource. If the referenced resource does not exist, the state of the ImportOperation will be set to unresolved until the referenced resource is created.

      Specified by:
      setKey in interface KeyReference
      Parameters:
      key - value to be set
    • equals

      public boolean equals(Object o)
      Overrides:
      equals in class Object
    • hashCode

      public int hashCode()
      Overrides:
      hashCode in class Object
    • toString

      public String toString()
      Overrides:
      toString in class Object
    • copyDeep

      public OrderKeyReference copyDeep()
      Specified by:
      copyDeep in interface KeyReference
      Specified by:
      copyDeep in interface OrderKeyReference