Interface LocalizedEnumSetField

All Superinterfaces:
CustomField
All Known Implementing Classes:
LocalizedEnumSetFieldImpl

public interface LocalizedEnumSetField extends CustomField

A field with a localized enum set value.


Example to create an instance using the builder pattern

     LocalizedEnumSetField localizedEnumSetField = LocalizedEnumSetField.builder()
             .plusValue(valueBuilder -> valueBuilder)
             .build()
 
  • Field Details

    • LOCALIZED_ENUM_SET

      static final String LOCALIZED_ENUM_SET
      discriminator value for LocalizedEnumSetField
      See Also:
  • Method Details

    • getValue

      @NotNull @NotNull List<String> getValue()

      JSON array of localized enum values, each represented by its key. Each key must match the key of an CustomFieldLocalizedEnumValue in the CustomFieldLocalizedEnumType. The order of items in the array is not fixed.

      Returns:
      value
    • setValue

      void setValue(String... value)

      JSON array of localized enum values, each represented by its key. Each key must match the key of an CustomFieldLocalizedEnumValue in the CustomFieldLocalizedEnumType. The order of items in the array is not fixed.

      Parameters:
      value - values to be set
    • setValue

      void setValue(List<String> value)

      JSON array of localized enum values, each represented by its key. Each key must match the key of an CustomFieldLocalizedEnumValue in the CustomFieldLocalizedEnumType. The order of items in the array is not fixed.

      Parameters:
      value - values to be set
    • of

      static LocalizedEnumSetField of()
      factory method
      Returns:
      instance of LocalizedEnumSetField
    • of

      factory method to create a shallow copy LocalizedEnumSetField
      Parameters:
      template - instance to be copied
      Returns:
      copy instance
    • copyDeep

      Specified by:
      copyDeep in interface CustomField
    • deepCopy

      @Nullable static LocalizedEnumSetField deepCopy(@Nullable LocalizedEnumSetField template)
      factory method to create a deep copy of LocalizedEnumSetField
      Parameters:
      template - instance to be copied
      Returns:
      copy instance
    • builder

      static LocalizedEnumSetFieldBuilder builder()
      builder factory method for LocalizedEnumSetField
      Returns:
      builder
    • builder

      create builder for LocalizedEnumSetField instance
      Parameters:
      template - instance with prefilled values for the builder
      Returns:
      builder
    • withLocalizedEnumSetField

      default <T> T withLocalizedEnumSetField(Function<LocalizedEnumSetField,T> helper)
      accessor map function
      Type Parameters:
      T - mapped type
      Parameters:
      helper - function to map the object
      Returns:
      mapped value
    • typeReference

      static com.fasterxml.jackson.core.type.TypeReference<LocalizedEnumSetField> typeReference()
      gives a TypeReference for usage with Jackson DataBind
      Returns:
      TypeReference