Class LocalizedStringSetFieldImpl
java.lang.Object
com.commercetools.importapi.models.customfields.LocalizedStringSetFieldImpl
- All Implemented Interfaces:
CustomField,LocalizedStringSetField,io.vrap.rmf.base.client.ModelBase
public class LocalizedStringSetFieldImpl
extends Object
implements LocalizedStringSetField, io.vrap.rmf.base.client.ModelBase
A field with a localized string set value.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.importapi.models.customfields.LocalizedStringSetField
LOCALIZED_STRING_SET -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetType()The type of this field.getValue()JSON array of localized strings.inthashCode()voidsetValue(LocalizedString... value) JSON array of localized strings.voidsetValue(List<LocalizedString> value) JSON array of localized strings.toString()Methods inherited from interface com.commercetools.importapi.models.customfields.CustomField
withCustomFieldMethods inherited from interface com.commercetools.importapi.models.customfields.LocalizedStringSetField
withLocalizedStringSetFieldMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
LocalizedStringSetFieldImpl
public LocalizedStringSetFieldImpl()create empty instance
-
-
Method Details
-
getType
The type of this field.
- Specified by:
getTypein interfaceCustomField- Returns:
- type
-
getValue
JSON array of localized strings. The order of items in the array is not fixed.
- Specified by:
getValuein interfaceLocalizedStringSetField- Returns:
- value
-
setValue
Description copied from interface:LocalizedStringSetFieldJSON array of localized strings. The order of items in the array is not fixed.
- Specified by:
setValuein interfaceLocalizedStringSetField- Parameters:
value- values to be set
-
setValue
Description copied from interface:LocalizedStringSetFieldJSON array of localized strings. The order of items in the array is not fixed.
- Specified by:
setValuein interfaceLocalizedStringSetField- Parameters:
value- values to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceCustomField- Specified by:
copyDeepin interfaceLocalizedStringSetField
-