Class ReferenceSetFieldImpl
java.lang.Object
com.commercetools.importapi.models.customfields.ReferenceSetFieldImpl
- All Implemented Interfaces:
CustomField,ReferenceSetField,io.vrap.rmf.base.client.ModelBase
public class ReferenceSetFieldImpl
extends Object
implements ReferenceSetField, io.vrap.rmf.base.client.ModelBase
A field with a reference set value.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.importapi.models.customfields.ReferenceSetField
REFERENCE_SET -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetType()The type of this field.getValue()JSON array of references, each referencing an existing resource by key.inthashCode()voidsetValue(KeyReference... value) JSON array of references, each referencing an existing resource by key.voidsetValue(List<KeyReference> value) JSON array of references, each referencing an existing resource by key.toString()Methods inherited from interface com.commercetools.importapi.models.customfields.CustomField
withCustomFieldMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.importapi.models.customfields.ReferenceSetField
withReferenceSetField
-
Constructor Details
-
ReferenceSetFieldImpl
public ReferenceSetFieldImpl()create empty instance
-
-
Method Details
-
getType
The type of this field.
- Specified by:
getTypein interfaceCustomField- Returns:
- type
-
getValue
JSON array of references, each referencing an existing resource by key. The order of items in the array is not fixed.
- Specified by:
getValuein interfaceReferenceSetField- Returns:
- value
-
setValue
Description copied from interface:ReferenceSetFieldJSON array of references, each referencing an existing resource by key. The order of items in the array is not fixed.
- Specified by:
setValuein interfaceReferenceSetField- Parameters:
value- values to be set
-
setValue
Description copied from interface:ReferenceSetFieldJSON array of references, each referencing an existing resource by key. The order of items in the array is not fixed.
- Specified by:
setValuein interfaceReferenceSetField- Parameters:
value- values to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceCustomField- Specified by:
copyDeepin interfaceReferenceSetField
-