Class StringSetFieldImpl
java.lang.Object
com.commercetools.importapi.models.customfields.StringSetFieldImpl
- All Implemented Interfaces:
CustomField,StringSetField,io.vrap.rmf.base.client.ModelBase
public class StringSetFieldImpl
extends Object
implements StringSetField, io.vrap.rmf.base.client.ModelBase
A field with a string set value.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.importapi.models.customfields.StringSetField
STRING_SET -
Constructor Summary
Constructors -
Method Summary
Methods inherited from interface com.commercetools.importapi.models.customfields.CustomField
withCustomFieldMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.importapi.models.customfields.StringSetField
withStringSetField
-
Constructor Details
-
StringSetFieldImpl
public StringSetFieldImpl()create empty instance
-
-
Method Details
-
getType
The type of this field.
- Specified by:
getTypein interfaceCustomField- Returns:
- type
-
getValue
JSON array of strings. The order of items in the array is not fixed.
- Specified by:
getValuein interfaceStringSetField- Returns:
- value
-
setValue
Description copied from interface:StringSetFieldJSON array of strings. The order of items in the array is not fixed.
- Specified by:
setValuein interfaceStringSetField- Parameters:
value- values to be set
-
setValue
Description copied from interface:StringSetFieldJSON array of strings. The order of items in the array is not fixed.
- Specified by:
setValuein interfaceStringSetField- Parameters:
value- values to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceCustomField- Specified by:
copyDeepin interfaceStringSetField
-