Class ConcurrentModificationErrorImpl
- All Implemented Interfaces:
ConcurrentModificationError,ErrorObject,io.vrap.rmf.base.client.ModelBase
The request conflicts with the current state of the involved resources. This error typically occurs when the request attempts to modify a resource that is out of date, that is, it has been modified by another client since the last time it was retrieved by the system attempting to update it. The client application should resolve the conflict (with or without involving the end-user) before retrying the request.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.importapi.models.errors.ConcurrentModificationError
CONCURRENT_MODIFICATION -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()An error identifier.The resource in conflict.The current version of the resource.A plain language description of the cause of an error.The version specified in the failed request.inthashCode()voidsetConflictedResource(Object conflictedResource) The resource in conflict.voidsetCurrentVersion(Long currentVersion) The current version of the resource.voidsetMessage(String message) A plain language description of the cause of an error.voidsetSpecifiedVersion(Long specifiedVersion) The version specified in the failed request.toString()Methods inherited from interface com.commercetools.importapi.models.errors.ConcurrentModificationError
withConcurrentModificationErrorMethods inherited from interface com.commercetools.importapi.models.errors.ErrorObject
withErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
ConcurrentModificationErrorImpl
public ConcurrentModificationErrorImpl()create empty instance
-
-
Method Details
-
getCode
An error identifier.
- Specified by:
getCodein interfaceErrorObject- Returns:
- code
-
getMessage
A plain language description of the cause of an error.
- Specified by:
getMessagein interfaceErrorObject- Returns:
- message
-
getSpecifiedVersion
The version specified in the failed request.
- Specified by:
getSpecifiedVersionin interfaceConcurrentModificationError- Returns:
- specifiedVersion
-
getCurrentVersion
The current version of the resource.
- Specified by:
getCurrentVersionin interfaceConcurrentModificationError- Returns:
- currentVersion
-
getConflictedResource
The resource in conflict.
- Specified by:
getConflictedResourcein interfaceConcurrentModificationError- Returns:
- conflictedResource
-
setMessage
Description copied from interface:ErrorObjectA plain language description of the cause of an error.
- Specified by:
setMessagein interfaceErrorObject- Parameters:
message- value to be set
-
setSpecifiedVersion
Description copied from interface:ConcurrentModificationErrorThe version specified in the failed request.
- Specified by:
setSpecifiedVersionin interfaceConcurrentModificationError- Parameters:
specifiedVersion- value to be set
-
setCurrentVersion
Description copied from interface:ConcurrentModificationErrorThe current version of the resource.
- Specified by:
setCurrentVersionin interfaceConcurrentModificationError- Parameters:
currentVersion- value to be set
-
setConflictedResource
Description copied from interface:ConcurrentModificationErrorThe resource in conflict.
- Specified by:
setConflictedResourcein interfaceConcurrentModificationError- Parameters:
conflictedResource- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceConcurrentModificationError- Specified by:
copyDeepin interfaceErrorObject
-