Class ContentionErrorImpl
java.lang.Object
com.commercetools.importapi.models.errors.ContentionErrorImpl
- All Implemented Interfaces:
ContentionError,ErrorObject,io.vrap.rmf.base.client.ModelBase
public class ContentionErrorImpl
extends Object
implements ContentionError, io.vrap.rmf.base.client.ModelBase
ContentionError
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.importapi.models.errors.ContentionError
CONTENTION -
Constructor Summary
Constructors -
Method Summary
Methods inherited from interface com.commercetools.importapi.models.errors.ContentionError
withContentionErrorMethods inherited from interface com.commercetools.importapi.models.errors.ErrorObject
withErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
ContentionErrorImpl
public ContentionErrorImpl()create empty instance
-
-
Method Details
-
getCode
An error identifier.
- Specified by:
getCodein interfaceErrorObject- Returns:
- code
-
getMessage
A plain language description of the cause of an error.
- Specified by:
getMessagein interfaceErrorObject- Returns:
- message
-
setMessage
Description copied from interface:ErrorObjectA plain language description of the cause of an error.
- Specified by:
setMessagein interfaceErrorObject- Parameters:
message- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceContentionError- Specified by:
copyDeepin interfaceErrorObject
-