Class DuplicateAttributeValueErrorImpl
java.lang.Object
com.commercetools.importapi.models.errors.DuplicateAttributeValueErrorImpl
- All Implemented Interfaces:
DuplicateAttributeValueError,ErrorObject,io.vrap.rmf.base.client.ModelBase
public class DuplicateAttributeValueErrorImpl
extends Object
implements DuplicateAttributeValueError, io.vrap.rmf.base.client.ModelBase
The Unique AttributeConstraintEnum was violated.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.importapi.models.errors.DuplicateAttributeValueError
DUPLICATE_ATTRIBUTE_VALUE -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleanThe attribute in conflict.getCode()An error identifier.A plain language description of the cause of an error.inthashCode()voidsetAttribute(Attribute attribute) The attribute in conflict.voidsetMessage(String message) A plain language description of the cause of an error.toString()Methods inherited from interface com.commercetools.importapi.models.errors.DuplicateAttributeValueError
withDuplicateAttributeValueErrorMethods inherited from interface com.commercetools.importapi.models.errors.ErrorObject
withErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
DuplicateAttributeValueErrorImpl
public DuplicateAttributeValueErrorImpl()create empty instance
-
-
Method Details
-
getCode
An error identifier.
- Specified by:
getCodein interfaceErrorObject- Returns:
- code
-
getMessage
A plain language description of the cause of an error.
- Specified by:
getMessagein interfaceErrorObject- Returns:
- message
-
getAttribute
The attribute in conflict.
- Specified by:
getAttributein interfaceDuplicateAttributeValueError- Returns:
- attribute
-
setMessage
Description copied from interface:ErrorObjectA plain language description of the cause of an error.
- Specified by:
setMessagein interfaceErrorObject- Parameters:
message- value to be set
-
setAttribute
Description copied from interface:DuplicateAttributeValueErrorThe attribute in conflict.
- Specified by:
setAttributein interfaceDuplicateAttributeValueError- Parameters:
attribute- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceDuplicateAttributeValueError- Specified by:
copyDeepin interfaceErrorObject
-