Class DuplicateAttributeValuesErrorImpl
java.lang.Object
com.commercetools.importapi.models.errors.DuplicateAttributeValuesErrorImpl
- All Implemented Interfaces:
DuplicateAttributeValuesError,ErrorObject,io.vrap.rmf.base.client.ModelBase
public class DuplicateAttributeValuesErrorImpl
extends Object
implements DuplicateAttributeValuesError, io.vrap.rmf.base.client.ModelBase
The CombinationUnique AttributeConstraintEnum was violated.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.importapi.models.errors.DuplicateAttributeValuesError
DUPLICATE_ATTRIBUTE_VALUES -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()An error identifier.A plain language description of the cause of an error.inthashCode()voidsetAttributes(Attribute... attributes) set attributesvoidsetAttributes(List<Attribute> attributes) set attributesvoidsetMessage(String message) A plain language description of the cause of an error.toString()Methods inherited from interface com.commercetools.importapi.models.errors.DuplicateAttributeValuesError
withDuplicateAttributeValuesErrorMethods inherited from interface com.commercetools.importapi.models.errors.ErrorObject
withErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
DuplicateAttributeValuesErrorImpl
public DuplicateAttributeValuesErrorImpl()create empty instance
-
-
Method Details
-
getCode
An error identifier.
- Specified by:
getCodein interfaceErrorObject- Returns:
- code
-
getMessage
A plain language description of the cause of an error.
- Specified by:
getMessagein interfaceErrorObject- Returns:
- message
-
getAttributes
- Specified by:
getAttributesin interfaceDuplicateAttributeValuesError- Returns:
- attributes
-
setMessage
Description copied from interface:ErrorObjectA plain language description of the cause of an error.
- Specified by:
setMessagein interfaceErrorObject- Parameters:
message- value to be set
-
setAttributes
Description copied from interface:DuplicateAttributeValuesErrorset attributes- Specified by:
setAttributesin interfaceDuplicateAttributeValuesError- Parameters:
attributes- values to be set
-
setAttributes
Description copied from interface:DuplicateAttributeValuesErrorset attributes- Specified by:
setAttributesin interfaceDuplicateAttributeValuesError- Parameters:
attributes- values to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceDuplicateAttributeValuesError- Specified by:
copyDeepin interfaceErrorObject
-