Class DuplicateFieldErrorImpl
java.lang.Object
com.commercetools.importapi.models.errors.DuplicateFieldErrorImpl
- All Implemented Interfaces:
DuplicateFieldError,ErrorObject,io.vrap.rmf.base.client.ModelBase
public class DuplicateFieldErrorImpl
extends Object
implements DuplicateFieldError, io.vrap.rmf.base.client.ModelBase
The given value already exists for a field that is checked for unique values.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.importapi.models.errors.DuplicateFieldError
DUPLICATE_FIELD -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()An error identifier.The offending duplicate value.getField()The name of the field.A plain language description of the cause of an error.inthashCode()voidsetDuplicateValue(Object duplicateValue) The offending duplicate value.voidThe name of the field.voidsetMessage(String message) A plain language description of the cause of an error.toString()Methods inherited from interface com.commercetools.importapi.models.errors.DuplicateFieldError
withDuplicateFieldErrorMethods inherited from interface com.commercetools.importapi.models.errors.ErrorObject
withErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
DuplicateFieldErrorImpl
public DuplicateFieldErrorImpl()create empty instance
-
-
Method Details
-
getCode
An error identifier.
- Specified by:
getCodein interfaceErrorObject- Returns:
- code
-
getMessage
A plain language description of the cause of an error.
- Specified by:
getMessagein interfaceErrorObject- Returns:
- message
-
getField
The name of the field.
- Specified by:
getFieldin interfaceDuplicateFieldError- Returns:
- field
-
getDuplicateValue
The offending duplicate value.
- Specified by:
getDuplicateValuein interfaceDuplicateFieldError- Returns:
- duplicateValue
-
setMessage
Description copied from interface:ErrorObjectA plain language description of the cause of an error.
- Specified by:
setMessagein interfaceErrorObject- Parameters:
message- value to be set
-
setField
Description copied from interface:DuplicateFieldErrorThe name of the field.
- Specified by:
setFieldin interfaceDuplicateFieldError- Parameters:
field- value to be set
-
setDuplicateValue
Description copied from interface:DuplicateFieldErrorThe offending duplicate value.
- Specified by:
setDuplicateValuein interfaceDuplicateFieldError- Parameters:
duplicateValue- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceDuplicateFieldError- Specified by:
copyDeepin interfaceErrorObject
-