Class DuplicateVariantValuesErrorImpl
java.lang.Object
com.commercetools.importapi.models.errors.DuplicateVariantValuesErrorImpl
- All Implemented Interfaces:
DuplicateVariantValuesError,ErrorObject,io.vrap.rmf.base.client.ModelBase
public class DuplicateVariantValuesErrorImpl
extends Object
implements DuplicateVariantValuesError, io.vrap.rmf.base.client.ModelBase
The given combination of values of a Product Variant conflicts with an existing one. Every Product Variant must have a distinct combination of SKU, prices, and custom attribute values.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.importapi.models.errors.DuplicateVariantValuesError
DUPLICATE_VARIANT_VALUES -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()An error identifier.A plain language description of the cause of an error.The offending variant values.inthashCode()voidsetMessage(String message) A plain language description of the cause of an error.voidsetVariantValues(VariantValues variantValues) The offending variant values.toString()Methods inherited from interface com.commercetools.importapi.models.errors.DuplicateVariantValuesError
withDuplicateVariantValuesErrorMethods inherited from interface com.commercetools.importapi.models.errors.ErrorObject
withErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
DuplicateVariantValuesErrorImpl
public DuplicateVariantValuesErrorImpl()create empty instance
-
-
Method Details
-
getCode
An error identifier.
- Specified by:
getCodein interfaceErrorObject- Returns:
- code
-
getMessage
A plain language description of the cause of an error.
- Specified by:
getMessagein interfaceErrorObject- Returns:
- message
-
getVariantValues
The offending variant values.
- Specified by:
getVariantValuesin interfaceDuplicateVariantValuesError- Returns:
- variantValues
-
setMessage
Description copied from interface:ErrorObjectA plain language description of the cause of an error.
- Specified by:
setMessagein interfaceErrorObject- Parameters:
message- value to be set
-
setVariantValues
Description copied from interface:DuplicateVariantValuesErrorThe offending variant values.
- Specified by:
setVariantValuesin interfaceDuplicateVariantValuesError- Parameters:
variantValues- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceDuplicateVariantValuesError- Specified by:
copyDeepin interfaceErrorObject
-