Class ErrorResponseImpl
java.lang.Object
com.commercetools.importapi.models.errors.ErrorResponseImpl
- All Implemented Interfaces:
ErrorResponse,io.vrap.rmf.base.client.ModelBase
public class ErrorResponseImpl
extends Object
implements ErrorResponse, io.vrap.rmf.base.client.ModelBase
The response in case of an error.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetError()This property is only used for OAuth2 errors.This property is only used for OAuth2 errors.The errors that caused this error response.Describes the error.The HTTP status code of the response.inthashCode()voidThis property is only used for OAuth2 errors.voidsetErrorDescription(String errorDescription) This property is only used for OAuth2 errors.voidsetErrors(ErrorObject... errors) The errors that caused this error response.voidsetErrors(List<ErrorObject> errors) The errors that caused this error response.voidsetMessage(String message) Describes the error.voidsetStatusCode(Integer statusCode) The HTTP status code of the response.toString()Methods inherited from interface com.commercetools.importapi.models.errors.ErrorResponse
withErrorResponseMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
ErrorResponseImpl
public ErrorResponseImpl()create empty instance
-
-
Method Details
-
getStatusCode
The HTTP status code of the response.
- Specified by:
getStatusCodein interfaceErrorResponse- Returns:
- statusCode
-
getMessage
Describes the error.
- Specified by:
getMessagein interfaceErrorResponse- Returns:
- message
-
getError
This property is only used for OAuth2 errors. Contains the error code.
- Specified by:
getErrorin interfaceErrorResponse- Returns:
- error
-
getErrorDescription
This property is only used for OAuth2 errors. Additional information to assist the client developer in understanding the error.
- Specified by:
getErrorDescriptionin interfaceErrorResponse- Returns:
- error_description
-
getErrors
The errors that caused this error response.
- Specified by:
getErrorsin interfaceErrorResponse- Returns:
- errors
-
setStatusCode
Description copied from interface:ErrorResponseThe HTTP status code of the response.
- Specified by:
setStatusCodein interfaceErrorResponse- Parameters:
statusCode- value to be set
-
setMessage
Description copied from interface:ErrorResponseDescribes the error.
- Specified by:
setMessagein interfaceErrorResponse- Parameters:
message- value to be set
-
setError
Description copied from interface:ErrorResponseThis property is only used for OAuth2 errors. Contains the error code.
- Specified by:
setErrorin interfaceErrorResponse- Parameters:
error- value to be set
-
setErrorDescription
Description copied from interface:ErrorResponseThis property is only used for OAuth2 errors. Additional information to assist the client developer in understanding the error.
- Specified by:
setErrorDescriptionin interfaceErrorResponse- Parameters:
errorDescription- value to be set
-
setErrors
Description copied from interface:ErrorResponseThe errors that caused this error response.
- Specified by:
setErrorsin interfaceErrorResponse- Parameters:
errors- values to be set
-
setErrors
Description copied from interface:ErrorResponseThe errors that caused this error response.
- Specified by:
setErrorsin interfaceErrorResponse- Parameters:
errors- values to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorResponse
-