Class GenericErrorImpl

java.lang.Object
com.commercetools.importapi.models.errors.GenericErrorImpl
All Implemented Interfaces:
ErrorObject, GenericError, io.vrap.rmf.base.client.ModelBase

public class GenericErrorImpl extends Object implements GenericError, io.vrap.rmf.base.client.ModelBase
GenericError
  • Nested Class Summary

    Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase

    io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle
  • Field Summary

    Fields inherited from interface com.commercetools.importapi.models.errors.GenericError

    GENERIC
  • Constructor Summary

    Constructors
    Constructor
    Description
    create empty instance
  • Method Summary

    Modifier and Type
    Method
    Description
     
    boolean
     
    An error identifier.
    A plain language description of the cause of an error.
    int
     
    void
    setMessage(String message)
    A plain language description of the cause of an error.
     

    Methods inherited from class java.lang.Object

    getClass, notify, notifyAll, wait, wait, wait

    Methods inherited from interface com.commercetools.importapi.models.errors.ErrorObject

    withErrorObject

    Methods inherited from interface com.commercetools.importapi.models.errors.GenericError

    withGenericError

    Methods inherited from interface io.vrap.rmf.base.client.ModelBase

    reflectionString, reflectionString
  • Constructor Details

    • GenericErrorImpl

      public GenericErrorImpl()
      create empty instance
  • Method Details