Class InvalidFieldErrorImpl
java.lang.Object
com.commercetools.importapi.models.errors.InvalidFieldErrorImpl
- All Implemented Interfaces:
ErrorObject,InvalidFieldError,io.vrap.rmf.base.client.ModelBase
public class InvalidFieldErrorImpl
extends Object
implements InvalidFieldError, io.vrap.rmf.base.client.ModelBase
A given field is not supported. This error occurs, for example, if the field variants, which is not supported by Product Import, is sent to the Product Import endpoint.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.importapi.models.errors.InvalidFieldError
INVALID_FIELD -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleanThe set of allowed values for the field, if any.getCode()An error identifier.getField()The name of the field.The invalid value.A plain language description of the cause of an error.The index of the resource in the import request that contains the invalid field.inthashCode()voidsetAllowedValues(Object... allowedValues) The set of allowed values for the field, if any.voidsetAllowedValues(List<Object> allowedValues) The set of allowed values for the field, if any.voidThe name of the field.voidsetInvalidValue(Object invalidValue) The invalid value.voidsetMessage(String message) A plain language description of the cause of an error.voidsetResourceIndex(Long resourceIndex) The index of the resource in the import request that contains the invalid field.toString()Methods inherited from interface com.commercetools.importapi.models.errors.ErrorObject
withErrorObjectMethods inherited from interface com.commercetools.importapi.models.errors.InvalidFieldError
withInvalidFieldErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
InvalidFieldErrorImpl
public InvalidFieldErrorImpl()create empty instance
-
-
Method Details
-
getCode
An error identifier.
- Specified by:
getCodein interfaceErrorObject- Returns:
- code
-
getMessage
A plain language description of the cause of an error.
- Specified by:
getMessagein interfaceErrorObject- Returns:
- message
-
getField
The name of the field.
- Specified by:
getFieldin interfaceInvalidFieldError- Returns:
- field
-
getInvalidValue
The invalid value.
- Specified by:
getInvalidValuein interfaceInvalidFieldError- Returns:
- invalidValue
-
getAllowedValues
The set of allowed values for the field, if any.
- Specified by:
getAllowedValuesin interfaceInvalidFieldError- Returns:
- allowedValues
-
getResourceIndex
The index of the resource in the import request that contains the invalid field.
- Specified by:
getResourceIndexin interfaceInvalidFieldError- Returns:
- resourceIndex
-
setMessage
Description copied from interface:ErrorObjectA plain language description of the cause of an error.
- Specified by:
setMessagein interfaceErrorObject- Parameters:
message- value to be set
-
setField
Description copied from interface:InvalidFieldErrorThe name of the field.
- Specified by:
setFieldin interfaceInvalidFieldError- Parameters:
field- value to be set
-
setInvalidValue
Description copied from interface:InvalidFieldErrorThe invalid value.
- Specified by:
setInvalidValuein interfaceInvalidFieldError- Parameters:
invalidValue- value to be set
-
setAllowedValues
Description copied from interface:InvalidFieldErrorThe set of allowed values for the field, if any.
- Specified by:
setAllowedValuesin interfaceInvalidFieldError- Parameters:
allowedValues- values to be set
-
setAllowedValues
Description copied from interface:InvalidFieldErrorThe set of allowed values for the field, if any.
- Specified by:
setAllowedValuesin interfaceInvalidFieldError- Parameters:
allowedValues- values to be set
-
setResourceIndex
Description copied from interface:InvalidFieldErrorThe index of the resource in the import request that contains the invalid field.
- Specified by:
setResourceIndexin interfaceInvalidFieldError- Parameters:
resourceIndex- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfaceInvalidFieldError
-