Class InvalidInputImpl

java.lang.Object
com.commercetools.importapi.models.errors.InvalidInputImpl
All Implemented Interfaces:
ErrorObject, InvalidInput, io.vrap.rmf.base.client.ModelBase

public class InvalidInputImpl extends Object implements InvalidInput, io.vrap.rmf.base.client.ModelBase

An invalid input has been sent to the service. The client application should validate the input according to the constraints described in the error message before sending the request again.

  • Nested Class Summary

    Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase

    io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle
  • Field Summary

    Fields inherited from interface com.commercetools.importapi.models.errors.InvalidInput

    INVALID_INPUT
  • Constructor Summary

    Constructors
    Constructor
    Description
    create empty instance
  • Method Summary

    Modifier and Type
    Method
    Description
     
    boolean
     
    An error identifier.
    A plain language description of the cause of an error.
    int
     
    void
    setMessage(String message)
    A plain language description of the cause of an error.
     

    Methods inherited from class java.lang.Object

    getClass, notify, notifyAll, wait, wait, wait

    Methods inherited from interface com.commercetools.importapi.models.errors.ErrorObject

    withErrorObject

    Methods inherited from interface com.commercetools.importapi.models.errors.InvalidInput

    withInvalidInput

    Methods inherited from interface io.vrap.rmf.base.client.ModelBase

    reflectionString, reflectionString
  • Constructor Details

    • InvalidInputImpl

      public InvalidInputImpl()
      create empty instance
  • Method Details