Class InvalidOperationImpl
java.lang.Object
com.commercetools.importapi.models.errors.InvalidOperationImpl
- All Implemented Interfaces:
ErrorObject,InvalidOperation,io.vrap.rmf.base.client.ModelBase
public class InvalidOperationImpl
extends Object
implements InvalidOperation, io.vrap.rmf.base.client.ModelBase
The resources in the request are not in the valid state for the operation. The client application should validate the constraints described in the error message before sending the request again.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.importapi.models.errors.InvalidOperation
INVALID_OPERATION -
Constructor Summary
Constructors -
Method Summary
Methods inherited from interface com.commercetools.importapi.models.errors.ErrorObject
withErrorObjectMethods inherited from interface com.commercetools.importapi.models.errors.InvalidOperation
withInvalidOperationMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
InvalidOperationImpl
public InvalidOperationImpl()create empty instance
-
-
Method Details
-
getCode
An error identifier.
- Specified by:
getCodein interfaceErrorObject- Returns:
- code
-
getMessage
A plain language description of the cause of an error.
- Specified by:
getMessagein interfaceErrorObject- Returns:
- message
-
setMessage
Description copied from interface:ErrorObjectA plain language description of the cause of an error.
- Specified by:
setMessagein interfaceErrorObject- Parameters:
message- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfaceInvalidOperation
-