Class InvalidScopeErrorImpl
java.lang.Object
com.commercetools.importapi.models.errors.InvalidScopeErrorImpl
- All Implemented Interfaces:
ErrorObject,InvalidScopeError,io.vrap.rmf.base.client.ModelBase
public class InvalidScopeErrorImpl
extends Object
implements InvalidScopeError, io.vrap.rmf.base.client.ModelBase
The requested scope is invalid, unknown, malformed, or exceeds the scope granted by the resource owner.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.importapi.models.errors.InvalidScopeError
INVALID_SCOPE -
Constructor Summary
Constructors -
Method Summary
Methods inherited from interface com.commercetools.importapi.models.errors.ErrorObject
withErrorObjectMethods inherited from interface com.commercetools.importapi.models.errors.InvalidScopeError
withInvalidScopeErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
InvalidScopeErrorImpl
public InvalidScopeErrorImpl()create empty instance
-
-
Method Details
-
getCode
An error identifier.
- Specified by:
getCodein interfaceErrorObject- Returns:
- code
-
getMessage
A plain language description of the cause of an error.
- Specified by:
getMessagein interfaceErrorObject- Returns:
- message
-
setMessage
Description copied from interface:ErrorObjectA plain language description of the cause of an error.
- Specified by:
setMessagein interfaceErrorObject- Parameters:
message- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfaceInvalidScopeError
-