Interface NewMasterVariantAdditionNotAllowedError

All Superinterfaces:
ErrorObject
All Known Implementing Classes:
NewMasterVariantAdditionNotAllowedErrorImpl

public interface NewMasterVariantAdditionNotAllowedError extends ErrorObject

Returned when attempting to create a ProductVariant and set it as the Master Variant in the same ProductVariantImport.


Example to create an instance using the builder pattern

     NewMasterVariantAdditionNotAllowedError newMasterVariantAdditionNotAllowedError = NewMasterVariantAdditionNotAllowedError.builder()
             .message("{message}")
             .build()