Class NewMasterVariantAdditionNotAllowedErrorImpl
java.lang.Object
com.commercetools.importapi.models.errors.NewMasterVariantAdditionNotAllowedErrorImpl
- All Implemented Interfaces:
ErrorObject,NewMasterVariantAdditionNotAllowedError,io.vrap.rmf.base.client.ModelBase
public class NewMasterVariantAdditionNotAllowedErrorImpl
extends Object
implements NewMasterVariantAdditionNotAllowedError, io.vrap.rmf.base.client.ModelBase
Returned when attempting to create a ProductVariant and set it as the Master Variant in the same ProductVariantImport.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.importapi.models.errors.NewMasterVariantAdditionNotAllowedError
NEW_MASTER_VARIANT_ADDITION_NOT_ALLOWED -
Constructor Summary
Constructors -
Method Summary
Methods inherited from interface com.commercetools.importapi.models.errors.ErrorObject
withErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.importapi.models.errors.NewMasterVariantAdditionNotAllowedError
withNewMasterVariantAdditionNotAllowedError
-
Constructor Details
-
NewMasterVariantAdditionNotAllowedErrorImpl
public NewMasterVariantAdditionNotAllowedErrorImpl()create empty instance
-
-
Method Details
-
getCode
An error identifier.
- Specified by:
getCodein interfaceErrorObject- Returns:
- code
-
getMessage
"Adding a new variant as master variant is not allowed."- Specified by:
getMessagein interfaceErrorObject- Specified by:
getMessagein interfaceNewMasterVariantAdditionNotAllowedError- Returns:
- message
-
setMessage
Description copied from interface:NewMasterVariantAdditionNotAllowedError"Adding a new variant as master variant is not allowed."- Specified by:
setMessagein interfaceErrorObject- Specified by:
setMessagein interfaceNewMasterVariantAdditionNotAllowedError- Parameters:
message- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfaceNewMasterVariantAdditionNotAllowedError
-