Class ResourceCreationErrorImpl
java.lang.Object
com.commercetools.importapi.models.errors.ResourceCreationErrorImpl
- All Implemented Interfaces:
ErrorObject,ResourceCreationError,io.vrap.rmf.base.client.ModelBase
public class ResourceCreationErrorImpl
extends Object
implements ResourceCreationError, io.vrap.rmf.base.client.ModelBase
ResourceCreationError
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.importapi.models.errors.ResourceCreationError
RESOURCE_CREATION -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()An error identifier.A plain language description of the cause of an error.The resource that was created.inthashCode()voidsetMessage(String message) A plain language description of the cause of an error.voidsetResource(Object resource) The resource that was created.toString()Methods inherited from interface com.commercetools.importapi.models.errors.ErrorObject
withErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.importapi.models.errors.ResourceCreationError
withResourceCreationError
-
Constructor Details
-
ResourceCreationErrorImpl
public ResourceCreationErrorImpl()create empty instance
-
-
Method Details
-
getCode
An error identifier.
- Specified by:
getCodein interfaceErrorObject- Returns:
- code
-
getMessage
A plain language description of the cause of an error.
- Specified by:
getMessagein interfaceErrorObject- Returns:
- message
-
getResource
The resource that was created.
- Specified by:
getResourcein interfaceResourceCreationError- Returns:
- resource
-
setMessage
Description copied from interface:ErrorObjectA plain language description of the cause of an error.
- Specified by:
setMessagein interfaceErrorObject- Parameters:
message- value to be set
-
setResource
Description copied from interface:ResourceCreationErrorThe resource that was created.
- Specified by:
setResourcein interfaceResourceCreationError- Parameters:
resource- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfaceResourceCreationError
-