Class ResourceNotFoundErrorImpl
java.lang.Object
com.commercetools.importapi.models.errors.ResourceNotFoundErrorImpl
- All Implemented Interfaces:
ErrorObject,ResourceNotFoundError,io.vrap.rmf.base.client.ModelBase
public class ResourceNotFoundErrorImpl
extends Object
implements ResourceNotFoundError, io.vrap.rmf.base.client.ModelBase
ResourceNotFoundError
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.importapi.models.errors.ResourceNotFoundError
RESOURCE_NOT_FOUND -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()An error identifier.A plain language description of the cause of an error.The resource that was not found.inthashCode()voidsetMessage(String message) A plain language description of the cause of an error.voidsetResource(Object resource) The resource that was not found.toString()Methods inherited from interface com.commercetools.importapi.models.errors.ErrorObject
withErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.importapi.models.errors.ResourceNotFoundError
withResourceNotFoundError
-
Constructor Details
-
ResourceNotFoundErrorImpl
public ResourceNotFoundErrorImpl()create empty instance
-
-
Method Details
-
getCode
An error identifier.
- Specified by:
getCodein interfaceErrorObject- Returns:
- code
-
getMessage
A plain language description of the cause of an error.
- Specified by:
getMessagein interfaceErrorObject- Returns:
- message
-
getResource
The resource that was not found.
- Specified by:
getResourcein interfaceResourceNotFoundError- Returns:
- resource
-
setMessage
Description copied from interface:ErrorObjectA plain language description of the cause of an error.
- Specified by:
setMessagein interfaceErrorObject- Parameters:
message- value to be set
-
setResource
Description copied from interface:ResourceNotFoundErrorThe resource that was not found.
- Specified by:
setResourcein interfaceResourceNotFoundError- Parameters:
resource- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfaceResourceNotFoundError
-