Class ResourceUpdateErrorImpl
java.lang.Object
com.commercetools.importapi.models.errors.ResourceUpdateErrorImpl
- All Implemented Interfaces:
ErrorObject,ResourceUpdateError,io.vrap.rmf.base.client.ModelBase
public class ResourceUpdateErrorImpl
extends Object
implements ResourceUpdateError, io.vrap.rmf.base.client.ModelBase
ResourceUpdateError
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.importapi.models.errors.ResourceUpdateError
RESOURCE_UPDATE -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()An error identifier.A plain language description of the cause of an error.The resource that was updated.inthashCode()voidsetMessage(String message) A plain language description of the cause of an error.voidsetResource(Object resource) The resource that was updated.toString()Methods inherited from interface com.commercetools.importapi.models.errors.ErrorObject
withErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.importapi.models.errors.ResourceUpdateError
withResourceUpdateError
-
Constructor Details
-
ResourceUpdateErrorImpl
public ResourceUpdateErrorImpl()create empty instance
-
-
Method Details
-
getCode
An error identifier.
- Specified by:
getCodein interfaceErrorObject- Returns:
- code
-
getMessage
A plain language description of the cause of an error.
- Specified by:
getMessagein interfaceErrorObject- Returns:
- message
-
getResource
The resource that was updated.
- Specified by:
getResourcein interfaceResourceUpdateError- Returns:
- resource
-
setMessage
Description copied from interface:ErrorObjectA plain language description of the cause of an error.
- Specified by:
setMessagein interfaceErrorObject- Parameters:
message- value to be set
-
setResource
Description copied from interface:ResourceUpdateErrorThe resource that was updated.
- Specified by:
setResourcein interfaceResourceUpdateError- Parameters:
resource- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfaceResourceUpdateError
-