Class OrderKeyReferenceImpl
java.lang.Object
com.commercetools.importapi.models.common.OrderKeyReferenceImpl
- All Implemented Interfaces:
KeyReference,OrderKeyReference,io.vrap.rmf.base.client.ModelBase
public class OrderKeyReferenceImpl
extends Object
implements OrderKeyReference, io.vrap.rmf.base.client.ModelBase
References an order by key.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.importapi.models.common.OrderKeyReference
ORDER -
Constructor Summary
Constructors -
Method Summary
Methods inherited from interface com.commercetools.importapi.models.common.KeyReference
withKeyReferenceMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.importapi.models.common.OrderKeyReference
withOrderKeyReference
-
Constructor Details
-
OrderKeyReferenceImpl
public OrderKeyReferenceImpl()create empty instance
-
-
Method Details
-
getKey
User-defined unique identifier of the referenced resource. If the referenced resource does not exist, the
stateof the ImportOperation will be set tounresolveduntil the referenced resource is created.- Specified by:
getKeyin interfaceKeyReference- Returns:
- key
-
getTypeId
Type of referenced resource.
- Specified by:
getTypeIdin interfaceKeyReference- Returns:
- typeId
-
setKey
Description copied from interface:KeyReferenceUser-defined unique identifier of the referenced resource. If the referenced resource does not exist, the
stateof the ImportOperation will be set tounresolveduntil the referenced resource is created.- Specified by:
setKeyin interfaceKeyReference- Parameters:
key- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceKeyReference- Specified by:
copyDeepin interfaceOrderKeyReference
-