Class InvalidInputImpl
java.lang.Object
com.commercetools.importapi.models.errors.InvalidInputImpl
- All Implemented Interfaces:
ErrorObject,InvalidInput,io.vrap.rmf.base.client.ModelBase
public class InvalidInputImpl
extends Object
implements InvalidInput, io.vrap.rmf.base.client.ModelBase
An invalid input has been sent to the service. The client application should validate the input according to the constraints described in the error message before sending the request again.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.importapi.models.errors.InvalidInput
INVALID_INPUT -
Constructor Summary
Constructors -
Method Summary
Methods inherited from interface com.commercetools.importapi.models.errors.ErrorObject
withErrorObjectMethods inherited from interface com.commercetools.importapi.models.errors.InvalidInput
withInvalidInputMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
InvalidInputImpl
public InvalidInputImpl()create empty instance
-
-
Method Details
-
getCode
An error identifier.
- Specified by:
getCodein interfaceErrorObject- Returns:
- code
-
getMessage
A plain language description of the cause of an error.
- Specified by:
getMessagein interfaceErrorObject- Returns:
- message
-
setMessage
Description copied from interface:ErrorObjectA plain language description of the cause of an error.
- Specified by:
setMessagein interfaceErrorObject- Parameters:
message- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfaceInvalidInput
-